#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

### Folder ###

import requests
from typing import Dict
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from ..utils import get_header_from_token, token_path

message_for_params = """
mirinae folder move --id <folder ID> --to <destination folder ID>
    --id: Folder ID to move
    --to: Destination folder ID
"""

def move(
    params,
)-> Dict:
    # Check the parameters
    if params.id is None or params.to is None:
        print (message_for_params)
        return None, None

    # Set url and headers
    url = f"{FRAMEWORK_ENDPOINT}/folder/move/{params.id}"
    headers = get_header_from_token(token_path)

    # Set data
    data = {
        "parentFolderId": params.to,
    }

    response = requests.put(
        url,
        headers=headers,
        data=data,
    )

    return url, response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Text, Dict

# Local
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from ..utils import get_header_from_token, show_response


def call_dashboard(
    token_path: Text,
    service_name: Text,
    **kwargs,
)-> Dict:
    # 서비스 실행 URL
    url = f"{FRAMEWORK_ENDPOINT}/mydata/{service_name}"

    # 세션 데이터 로드
    headers = get_header_from_token(token_path)

    # 서비스 실행
    response = requests.get(
        url,
        headers=headers,
        data={},
    )
    if kwargs.get('verbose', False):
        show_response(f"Dashboard {service_name}", url, response)
    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

### Folder ###

import requests
from typing import Dict
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from ..utils import get_header_from_token, token_path

message_for_params = """
mirinae folder add --doc <document ID> --to <folder ID>
    --doc: Document ID
    --act: Action (add, remove)
    --to: Folder ID (optional, default: root)
"""

def doc(
    params,
)-> Dict:
    # Check the parameters
    if params.doc is None or params.act is None:
        print (message_for_params)
        return None, None

    if params.to is None:
        folder = "root"
    else:
        folder = params.to

    # Set url and headers
    url = f"{FRAMEWORK_ENDPOINT}/folder/doc/{folder}"
    headers = get_header_from_token(token_path)

    # Set data
    data = {
        "documentId": params.doc,
        "action": params.act,
    }

    response = requests.put(
        url,
        headers=headers,
        data=data,
    )

    return url, response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

### Folder ###

from ..utils.set_logging import get_logger

# Define
logger = get_logger(__name__.split('.')[-1])

# Local
from . import create, update, delete, move, doc, info
from ..utils.show import show_response

def folder(
    params,
)-> None:
    """Folder Management
    - Create, Delete, Update, Get

    Parameters
    ----------
    name : Text
        Folder name
    pfid : Text
        Parent folder ID
    """

    # Greeting
    logger.info("Folder management starts.")

    if params.create:
        url, response = create(params)
    elif params.update:
        url, response = update(params)
    elif params.move:
        url, response = move(params)
    elif params.doc:
        url, response = doc(params)
    elif params.delete:
        url, response = delete(params)
    elif params.get:
        url, response = info(params)
    else:
        logger.error("Please select a function!")
        return

    if url is None or response is None:
        logger.error("Please check the parameters.")
        return

    if params.verbose:
        show_response(
            title="Folder Management",
            url=url,
            response=response,
       )


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def update(args) -> Dict:
    """Update a project

    Args:
        id: Text - Project ID
        name: Text - Project name
        description: Text - Project description
        verbose: bool - Verbose mode

    >>> mirinae project update -v -id <id> --name <project_name> --description <project_description>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/project/{args.id}"

    # Get headers including access token
    headers = get_header_from_token()

    # Set the data to update
    data = {}
    if args.name:
        data["name"] = args.name
    if args.description:
        data["description"] = args.description

    # Send the request
    response = requests.put(
        url,
        headers=headers,
        data=data,
    )

    # Display the response
    if args.verbose:
        show_response("Update", url, response)

    return response



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
import json
from typing import Dict
from pathlib import Path

# Local
from .header import ACCESS_TOKEN_PATH, REFRESH_TOKEN_PATH
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import get_logger, show_response

# Define
logger = get_logger(__name__.split('.')[-1])

def regenerate_access_token(
    params,
)-> Dict:
    print (params)
    # Set URL
    url = f"{FRAMEWORK_ENDPOINT}/auth/refreshAccessToken"

    # Copy default headers
    headers = HEADERS.copy()

    # Get the refresh token from the header file
    cookie_data = json.loads(Path(REFRESH_TOKEN_PATH).read_text()).get('Set-Cookie')
    refresh_token = cookie_data.split('=')[1].split(';')[0]

    cookies = {
        "refreshToken": refresh_token
    }

    response = requests.post(url, headers=headers, cookies=cookies)
    # response.raise_for_status()  # Raise an error if the request fails

    # Parse the response
    data = response.json()
    if data.get("status") == "success":
        new_access_token = data["content"]["accessToken"]

        # Save the new access token to the token file
        Path(ACCESS_TOKEN_PATH).parent.mkdir(parents=True, exist_ok=True)
        open(ACCESS_TOKEN_PATH, 'w').write(json.dumps(response.json(), indent=4, ensure_ascii=False))

    else:
        print("Failed to refresh access token:", data.get("message", "Unknown error"))

    if params.verbose:
        show_response("Refresh Access Token", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .common import add_common_arguments
from .user import user_subparser
from .product import product_subparser
from .project import project_subparser
from .flow import flow_subparser

def load_parser(parser):

    # Common options
    add_common_arguments(parser)

    # Subparsers & use common options
    subparsers = parser.add_subparsers(
        dest="command",
        required=True,
        help="Command to execute",
    )
    user_subparser(subparsers)
    product_subparser(subparsers)
    project_subparser(subparsers)
    flow_subparser(subparsers)





#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .common import add_common_arguments

def product_subparser(subparsers):
    product_parser = subparsers.add_parser(
        "product",
        help="Product options",
    )

    add_common_arguments(product_parser)

    product_subparsers = product_parser.add_subparsers(
        dest="action",
        required=True,
        help="Product actions",
    )

    for action in ["create", "delete", "get", "update"]:
        action_parser = product_subparsers.add_parser(
            action,
            help=f"{action.capitalize()} product",
        )

        # Add common arguments to each action parser
        add_common_arguments(action_parser)

        action_parser.add_argument(
            "-f",
            "--file",
            help="Service product JSON file",
            type=str,
        )


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
import requests
from typing import Dict
from pathlib import Path

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response
from ..auth import ACCESS_TOKEN_PATH, REFRESH_TOKEN_PATH

def login(args) -> Dict:
    """Login

    Args:
        email: Text - Email
        password: Text - Password
        verbose: bool - Verbose mode
    """
    email = args.email
    password = args.password
    verbose = args.verbose

    url = f"{FRAMEWORK_ENDPOINT}/login"

    response = requests.post(
        url,
        headers=HEADERS,
        json={
            'email': email,
            'password': password
        },
    )

    # When the response is successful
    # `refresh_token` and `access_token` are stored in a file
    if response.status_code == 200:
        # Save the refresh token
        set_cookie = response.headers.get('Set-Cookie')
        Path(REFRESH_TOKEN_PATH).parent.mkdir(parents=True, exist_ok=True)
        open(REFRESH_TOKEN_PATH, 'w').write(json.dumps({'Set-Cookie': set_cookie}, indent=4, ensure_ascii=False))

        # Save the access token
        Path(ACCESS_TOKEN_PATH).parent.mkdir(parents=True, exist_ok=True)
        open(ACCESS_TOKEN_PATH, 'w').write(json.dumps(response.json(), indent=4, ensure_ascii=False))

    if verbose:
        show_response("Login", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
import requests
from typing import Dict
from pathlib import Path

# Local
from ..auth import REFRESH_TOKEN_PATH, ACCESS_TOKEN_PATH
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response, get_logger

# Define
logger = get_logger(__name__.split('.')[-1])

def refresh(args) -> Dict:
    """Refresh the user with refresh token

    Args:
        file: Text - Service product JSON file

    >>> mirianae user refresh --verbose
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/auth/refreshAccessToken"

    # Set headers
    headers = HEADERS.copy()

    # Set `cookies` from the `REFRESH_TOKEN_PATH` file
    if not Path(REFRESH_TOKEN_PATH).exists():
        logger.error(f"Refresh token file not found: {REFRESH_TOKEN_PATH}")
        return None

    try:
        cookie_data = json.loads(Path(REFRESH_TOKEN_PATH).read_text()).get('Set-Cookie')
        refresh_token = cookie_data.split('=')[1].split(';')[0]
    except Exception as e:
        logger.error(f"Failed to read refresh token: {e}")
        return None

    # Set the cookies
    cookies = {
        "refreshToken": refresh_token
    }

    # Send the request
    response = requests.post(
        url,
        headers=headers,
        cookies=cookies,
    )

    # Parse the response
    data = response.json()
    if data.get("status") == "success":
        new_access_token = data["content"]["accessToken"]

        # Save the new access token to the token file
        Path(ACCESS_TOKEN_PATH).parent.mkdir(parents=True, exist_ok=True)
        open(ACCESS_TOKEN_PATH, 'w').write(json.dumps(response.json(), indent=4, ensure_ascii=False))
        logger.info("Access token refreshed successfully.")
    else:
        logger.error(f"Failed to refresh access token: {data.get('message', 'Unknown error')}")
        return None

    if args.verbose:
        show_response("Refresh", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

# Mirinae CLI for Audion

import importlib
import argparse

# Local
from .parsers.load import load_parser
from .utils.set_logging import get_logger
from .utils.show import show_status

# Define
logger = get_logger(__name__.split('.')[-1])

def main():
    # Define parser
    parser = argparse.ArgumentParser(
        description='Simulator for Mirinae',
        formatter_class=argparse.RawTextHelpFormatter,
        add_help=False,
    )

    # Load parser with subparsers
    load_parser(parser)
    args = parser.parse_args()

    """ Execute command
    - Module is imported dynamically based on the command
    - Action is executed based on the command
    - Arguments are passed to the action

    >>> mirinae <command> <action> <args>
    """
    module = importlib.import_module(f'.{args.command}', package='mirinae')
    getattr(module, args.action)(args)


if __name__ == '__main__':
    main()


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

# Folder

import requests
from typing import Dict
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from ..utils import get_header_from_token, token_path

message_for_params = """
mirinae folder create --name <folder name> --to <parent folder ID>
    --name: Folder name
    --to: Parent folder ID (optional, default: root)
"""

def create(
    params,
)-> Dict:
    if params.name is None:
        print (message_for_params)
        return None, None

    url = f"{FRAMEWORK_ENDPOINT}/folder"
    headers = get_header_from_token(token_path)

    data = {
        "name": params.name,
    }
    if params.to:
        data["parentFolderId"] = params.to

    # POST: Create a folder with JSON file
    response = requests.post(
        url,
        headers=headers,
        data=data
    )

    return url, response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .refresh_token import regenerate_access_token
from .header import get_header_from_token, ACCESS_TOKEN_PATH, REFRESH_TOKEN_PATH


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .common import add_common_arguments

def project_subparser(subparsers):
    project_parser = subparsers.add_parser(
        "project",
        help="Project options",
    )

    add_common_arguments(project_parser)

    project_subparsers = project_parser.add_subparsers(
        dest="action",
        required=True,
        help="Project actions",
    )

    for action in ["create", "delete", "get", "update", "copy"]:
        action_parser = project_subparsers.add_parser(
            action,
            help=f"{action.capitalize()} project",
        )

        # Add common arguments to each action parser
        add_common_arguments(action_parser)





#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import pandas as pd
from datetime import datetime
from typing import Dict, Text


def display_voice_separation(
    data: Dict,
    query: Text,
)-> None:
    """Display subtitle generation"""
    # Load data
    # DataFrame 생성
    pd.set_option('display.max_colwidth', 20)
    df = pd.DataFrame(data)

    # s2t에서 decodingTime과 text를 병합하여 새로운 열로 추가
    # Text만 추가
    df["vocals"] = df["intrumentFiles"].apply(lambda x: x["vocals"])
    # df["s2t_info"] = df["s2t"].apply(lambda x: f"Decoding Time: {x['decodingTime']}, Text: {x['text']}")

    # 원하는 열만 선택하여 새로운 DataFrame 생성
    selected_columns = df[["id", "filePath", "vocals", "createdAt"]]

    # 출력
    if query == "last":
        display_last(selected_columns)
    elif query == "today":
        display_today(selected_columns)
    else:
        print(selected_columns)


def display_last(
    df: pd.DataFrame,
)-> None:
    # Check if the DataFrame is empty
    if df.empty:
        print("No data available")
        return

    """Get last subtitle generation"""
    pd.set_option('display.max_colwidth', 80)
    last_data = df.iloc[-1]
    print(last_data)


def display_today(
    df: pd.DataFrame,
)-> None:
    """Get today subtitle generation"""
    # 오늘 날짜와 같은 항목 필터링
    df['createdAt'] = pd.to_datetime(df['createdAt'])
    today = pd.to_datetime(datetime.now().date())  # 오늘의 날짜 (시간 없음)
    filtered_df = df[df['createdAt'].dt.date == today.date()]
    print(filtered_df)


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response

def create(args) -> Dict:
    """Create a product

    Args:
        file: Text - Service product JSON file

    >>> mirinae product create -v -f product.json
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/product"

    # Set headers
    headers = HEADERS.copy()

    # Send the request
    response = requests.post(
        url,
        headers=headers,
        files={
            'file': open(args.file, 'rb'),
        },
    )

    # Display the response
    if args.verbose:
        show_response("Create", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response

def update(args) -> Dict:
    """Update a product
    - In product management, the product ID means the product name.
    - Product update is only available for the product owner.
    - Product is updated with a new JSON file.

    Args:
        id: Text - Product ID
        file: Text - Service product JSON file

    >>> mirinae product update -v -f product.json -id audion_emo
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/product/{args.id}"

    # Set headers
    headers = HEADERS.copy()

    # Send the request
    response = requests.put(
        url,
        headers=headers,
        files={
            'file': open(args.file, 'rb'),
        },
    )

    # Display the response
    if args.verbose:
        show_response("Update", url, response)

    return response



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict
from pathlib import Path

# Local
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token, ACCESS_TOKEN_PATH
from ..utils import show_response

def logout(args) -> Dict:
    """Logout from the server
    """
    url = f"{FRAMEWORK_ENDPOINT}/logout"

    # Set headers with access token
    headers = get_header_from_token()

    # Request logout
    response = requests.post(url, headers=headers)

    # Unlink the access token
    if response.status_code == 200:
        if Path(ACCESS_TOKEN_PATH).exists():
            Path(ACCESS_TOKEN_PATH).unlink()

    # Show response
    if args.verbose:
        show_response("Logout", url, response)




#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local import
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def create(args) -> Dict:
    """Create a project
    - You can get product IDs using 'mirinae product get' command.
    (ex. mirinae product get -v)

    Args:
        id: Text - Product ID
        name: Text - Project name
        verbose: bool - Verbose mode
    Returns:
        Dict: Response

    >>> mirinae project create -v -id <product_id> --name <project_name>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/project/{args.id}"

    # Get headers including access token
    headers = get_header_from_token()

    # Send the request
    project_name = args.name if args.name else ""
    response = requests.post(
        url,
        headers=headers,
        data={
            "name": project_name
        }
    )

    # Display the response
    if args.verbose:
        show_response("Create", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local import
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def copy(args) -> Dict:
    """Copy a project for customizing with miscro-services

    Args:
        id: Text - Project ID
        verbose: bool - Verbose mode

    Returns:
        Dict: Response

    >>> mirinae project copy -v -id <project_id>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/project/{args.id}/copy"

    # Get headers including access token
    headers = get_header_from_token()

    # Send the request
    response = requests.post(
        url,
        headers=headers,
    )

    # Display the response
    if args.verbose:
        show_response("Copy", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .create import create
from .update import update
from .delete import delete
from .move import move
from .doc import doc
from .info import info



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response

def get(args) -> Dict:
    """Get a product
    - Get all products when no arguments are provided
    - Get products by name using regular expression when name is provided
    - Get a product by product ID when product ID is provided

    Args:
        id: Text - Product ID
        verbose: bool - Verbose mode

    >>> mirinae product get -v -id audion_emo
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/product"

    if args.product_id:
        url = url + f"?productId={args.id}"
    if args.name:
        url = url + f"?name={args.name}"

    # Set headers
    headers = HEADERS.copy()

    # Send the request
    response = requests.get(
        url,
        headers=headers,
    )

    # Display the response
    if args.verbose:
        show_response("Get", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
from typing import Any

# Local
from ..user.login import token_path
from ..core import (
    call_dashboard,
)
from ..utils import get_logger
from .subtitle_generation import display_subtitle_generation
from .voice_separation import display_voice_separation

# Define
logger = get_logger(__name__.split('.')[-1])


def dashboard(
    params,
)-> Any:
    # Greeting
    logger.info("Dashboard 호출을 시작합니다.")

    # Set options
    options = {}

    # Get service name
    service_name = params.service_name

    # Dashboard 호출
    if params.get:
        response = call_dashboard(
            token_path=token_path,
            service_name=params.service_name,
            verbose=params.verbose,
            **options,
        )

    # Show response
    width = 100
    if response.status_code == 200:
        # Save response
        save_path = f"{service_name}.json"
        json.dump(response.json(), open(save_path, 'w'), indent=4, ensure_ascii=False)
        logger.info(f"대시보드 데이터를 {save_path}에 저장하였습니다.")
        resp_data = response.json()
        print ("="*width)
        print (f"{params.service_name} Dashboard")
        print ("-"*width)
        print (f"Number of Data: {len(resp_data)}")
        print ("-"*width)


        if service_name == "VoiceSeparation":
            display_voice_separation(
                data=resp_data,
                query=params.query,
            )
        elif service_name == "SubtitleGeneration":
            display_subtitle_generation(
                data=resp_data,
                query=params.query,
            )
        else:
            pass







#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)


def add_common_arguments(parser):
    parser.add_argument(
        "--version",
        help="Show version and exit",
        action="store_true",
    )

    parser.add_argument(
        "-v",
        "--verbose",
        help="Verbose mode",
        action="store_true",
    )

    parser.add_argument(
        "-d",
        "--debug",
        help="Debug mode",
        action="store_true",
    )

    parser.add_argument(
        "-i",
        "--input",
        help="Input",
        type=str,
    )

    parser.add_argument(
        "-id",
        "--id",
        help="ID", # It could be a project_id, product_id, folder_id, ...
        type=str,
    )

    parser.add_argument(
        "-it",
        "--input-type",
        help="Input type (url, uri, file, text, ...)",
        type=str,
    )

    parser.add_argument(
        "-o",
        "--output",
        help="Output",
        type=str,
    )

    parser.add_argument(
        "-t",
        "--text",
        help="Text",
        type=str,
    )

    parser.add_argument(
        "--name",
        help="Name",
        type=str,
    )

    parser.add_argument(
        "--description",
        help="Description",
        type=str,
    )

    parser.add_argument(
        "-pj",
        "--project_id",
        help="Project ID",
        type=str,
    )

    parser.add_argument(
        "-pd",
        "--product_id",
        help="Product ID",
        type=str,
    )

    parser.add_argument(
        "-fid",
        "--folder_id",
        help="File ID",
        type=str,
    )

    # # Services
    # parser.add_argument("-ns", "--num-speakers", help="Number of speakers", type=int)
    # parser.add_argument("-q", "--query", help="Query", type=str)

    # # Folder
    # parser.add_argument("--field", help="Field", type=str)
    # parser.add_argument("-f", "--folder", help="Folder", type=str)
    # parser.add_argument("-pf", "--parent_folder", help="Parent folder", type=str)
    # parser.add_argument("-to", "--to", help="To", type=str)
    # parser.add_argument("-doc", "--document", help="Document", type=str)




#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
import argparse
from typing import Text, Dict
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from login import login, session
from ..utils.show import show_response

def subscribe(
    **kwargs,
)-> Dict[Text, Text]:
    url = f"{FRAMEWORK_ENDPOINT}/subscription"
    response = session.post(
        url,
        headers=HEADERS,
        data={
            "serviceName": kwargs.get("serviceName"),
            "planName": kwargs.get("planName"),
        }
    )
    show_response("Subscription", url, response)

def get_with_id(
    id: Text,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription/id/{id}"
    response = session.get(
        url,
        headers=HEADERS,
    )
    show_response("Get Subscription with ID", url, response)


def get_with_userId(
    userId: Text,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription/user/{userId}"
    response = session.get(
        url,
        headers=HEADERS,
    )
    show_response("Get Subscription with User ID", url, response)


def get_service_names_with_userId(
    userId: Text,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription/user/{userId}/serviceNames"
    response = session.get(
        url,
        headers=HEADERS,
    )
    show_response("Get Subscription with User ID", url, response)


def get_with_servicename(
    serviceName: Text,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription/service/{serviceName}"
    response = session.get(
        url,
        headers=HEADERS,
    )
    show_response("Get Subscription with Names", url, response)


def update_subscription(
    **kwargs,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription"
    response = session.put(
        url,
        headers=HEADERS,
        data={
            "serviceName": kwargs.get("serviceName"),
            "status": kwargs.get("status"),
        }
    )
    show_response("Update Subscription", url, response)

def delete_subscription(
    **kwargs,
)-> None:
    url = f"{FRAMEWORK_ENDPOINT}/subscription"
    response = session.delete(
        url,
        headers=HEADERS,
        data={
            "serviceName": kwargs.get("serviceName"),
        }
    )
    show_response("Delete Subscription", url, response)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-t", "--task", dest='task', type=str, default="get")
    parser.add_argument("-s", "--servcie-name", dest='service_name', type=str, default="NONE")
    parser.add_argument("-p", "--plan-name", dest='plan_name', type=str, default="NONE")
    parser.add_argument("-i", "--id", dest='id', type=str, default="NONE")
    parser.add_argument("-u", "--user-id", dest='user_id', type=str, default="NONE")
    parser.add_argument("-d", "--dashboard", action="store_true", help="Show the dashboard")
    args = parser.parse_args()

    # 로그인 후 세션 데이터를 가져옴
    sess_data = login(
        email="galois@holamago.com",
        password="finger2cyg",
    )
    print (json.dumps(sess_data, indent=4, ensure_ascii=False))

    task = args.task

    if task == "subscribe":
        subscribe(
            serviceName=args.service_name,
            planName=args.plan_name,
        )

    if task == "get":
        if args.id != "NONE":
            get_with_id(
                id=args.id,
            )
        if args.user_id != "NONE":
            get_with_userId(
                userId=args.user_id,
            )
        if args.service_name != "NONE":
            get_with_servicename(
                serviceName=args.service_name,
            )

    if task == "services":
        get_service_names_with_userId(
            userId=args.user_id,
        )

    if task == "update":
        update_subscription(
            serviceName=args.service_name,
            status="active",
        )

    if task == "delete":
        delete_subscription(
            serviceName=args.service_name,
        )


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .login import login
from .logout import logout
from .signup import signup
from .update import update
from .refresh import refresh
# from .delete import delete



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .common import add_common_arguments

def user_subparser(subparsers):
    user_parser = subparsers.add_parser(
        "user",
        help="User options",
    )

    add_common_arguments(user_parser)

    user_subparsers = user_parser.add_subparsers(
        dest="action",
        required=True,
        help="User actions",
    )

    for action in ["login", "logout", "signup", "update", "delete", "refresh"]:
        action_parser = user_subparsers.add_parser(
            action,
            help=f"{action.capitalize()} user",
        )

        # Add common arguments to each action parser
        add_common_arguments(action_parser)

        action_parser.add_argument(
            "-e",
            "--email",
            help="Email",
            type=str,
        )

        action_parser.add_argument(
            "-pw",
            "--password",
            help="Password",
            type=str,
        )

        action_parser.add_argument(
            "-u",
            "--username",
            help="Username",
            type=str,
        )

        action_parser.add_argument(
            "--organization",
            help="Organization",
            type=str,
        )

        action_parser.add_argument(
            "--job_title",
            help="Job title",
            type=str,
        )

        action_parser.add_argument(
            "--role",
            help="Role (admin, user, ...)",
            type=str,
        )

        action_parser.add_argument(
            "--status",
            help="Status (active, inactive, ...)",
            type=str,
        )


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def delete(
    params,
)-> Dict:
    """Delete a project
    - You can get project IDs using 'mirinae project get' command.
    (ex. mirinae project get -v)

    Args:
        id: Text - Project ID
        verbose: bool - Verbose mode
    Returns:
        Dict: Response

    >>> mirinae project delete -v -id <project_id>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/project/{params.id}"

    # Send the request
    response = requests.delete(
        url,
        headers=get_header_from_token(),
    )

    # Display the response
    if params.verbose:
        show_response("Delete", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def run(args) -> Dict:
    """Run a project pipeline

    Args:
        id: Text - Project ID
        input: Text - Input data (uri / url / file)
        input_type: Text - Input type (default: uri)
        folder_id: Text - Folder ID (optional)
        verbose: bool - Verbose mode

    Returns:
        Dict: Response

    >>> mirinae flow run -v -id <flow_id> --input <input_data> --input_type <input_type> --folder_id <folder_id>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/flow/{args.id}"

    # Get headers including access token
    headers = get_header_from_token()

    # Send the request
    data = {}

    # Set the input type (default: uri)
    if args.input_type:
        data["inputType"] = args.input_type
    else:
        data["inputType"] = "uri"

    # Set the folder ID (if not set, it will be set to the root folder)
    if args.folder_id:
        data["folderId"] = args.folder_id

    # Send the request
    # TODO: Change input data to the multiple data
    if args.input_type == "file":
        # Upload the file from the local path
        response = requests.post(
            url,
            headers=headers,
            data=data,
            files={
                'file': (args.input, open(args.input, 'rb'), f'audio/wav')
            }
        )
    else:
        # Send the input data (url or uri)
        json_data = data
        json_data["input"] = args.input

        response = requests.post(
            url,
            headers=headers,
            json=json_data,
        )

    # Display the response
    if args.verbose:
        show_response("Flow:Run", url, response)

    return response



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

### Folder ###

import requests
from typing import Dict
from ..config import (
    FRAMEWORK_ENDPOINT,
    HEADERS,
)
from ..utils import get_header_from_token, token_path

message_for_params = """
mirinae folder get --id <folder ID>
    --id: Folder ID to get (optional, default: root)
"""

def info(
    params,
)-> Dict:
    # Check the parameters
    if params.id is None:
        folder_id = "root"
    else:
        folder_id = params.id


    # Set url and headers
    url = f"{FRAMEWORK_ENDPOINT}/folder/{folder_id}"
    headers = get_header_from_token(token_path)

    response = requests.get(
        url,
        headers=headers,
    )

    return url, response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
from pathlib import Path
from typing import Text

# Define token path
ACCESS_TOKEN_PATH = f"{Path.home()}/.mirinae/access.json"

# Set header path when the token is not available
REFRESH_TOKEN_PATH = f"{Path.home()}/.mirinae/refresh.json"


def get_header_from_token():
    """Get session data header

    Parameters
    ----------
    token_path: Text
        Session data file path

    Returns
    -------
    dict
        Session data header
    """
    if not Path(ACCESS_TOKEN_PATH).exists():
        return {}

    with open(ACCESS_TOKEN_PATH, 'r') as f:
        sess_data = json.load(f)

    headers = {
        "Accept": "application/json",
        "Authorization": f"Bearer {sess_data.get('content', {}).get('accessToken', '')}"
    }

    return headers


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .common import add_common_arguments

def flow_subparser(subparsers):
    flow_parser = subparsers.add_parser(
        "flow",
        help="Flow options",
    )

    add_common_arguments(flow_parser)

    flow_subparsers = flow_parser.add_subparsers(
        dest="action",
        required=True,
        help="Flow actions",
    )

    for action in ["run"]:
        action_parser = flow_subparsers.add_parser(
            action,
            help=f"{action.capitalize()} flow",
        )

        # Add common arguments to each action parser
        add_common_arguments(action_parser)



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response

def delete(args) -> Dict:
    """Delete a product
    - Delete a product by product ID

    Args:
        id: Text - Product ID
        verbose: bool - Verbose mode

    >>> mirinae product delete -v -id audion_emo
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/product/{args.id}"

    # Set headers
    headers = HEADERS.copy()

    # Send the request
    response = requests.delete(
        url,
        headers=headers,
    )

    # Display the response
    if args.verbose:
        show_response("Delete", url, response)

    return response



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import get_logger, show_response

# Define
logger = get_logger(__name__.split('.')[-1])

def update(args) -> Dict:
    """Update

    Args:
        email: Text - Email
        password: Text - Password
        username: Text - Username
        company: Text - Company
        verbose: bool - Verbose mode

    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/user/update"

    # Set headers with access token
    headers = get_header_from_token()

    # Set data
    data = {}
    if args.email:      data['email'] = args.email
    if args.password:   data['password'] = args.password
    if args.username:   data['username'] = args.username
    if args.company:    data['company'] = args.company
    if args.status:     data['status'] = args.status

    # Send the request
    response = requests.put(
        url,
        headers=headers,
        json=data,
    )

    # Display the response
    if args.verbose:
        show_response("Update", url, response)

    return response




#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT, HEADERS
from ..utils import show_response
from ..auth import ACCESS_TOKEN_PATH, REFRESH_TOKEN_PATH

def signup(args) -> Dict:
    """Signup

    Args:
        email: Text - Email
        password: Text - Password
        username: Text - Username
        organization: Text - Organization
        verbose: bool - Verbose mode

    >>> mirinae user signup --email <email> --password <password> --username <username> --organization <organization>
    """
    # Get the arguments
    email = args.email
    password = args.password
    username = args.username
    organization = args.organization
    verbose = args.verbose

    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/signup"

    # Set data
    data = {
        'email': email,
        'password': password,
        'username': username,
        'organization': organization,
    }

    # Send the request
    response = requests.post(
        url,
        headers=HEADERS,
        json=data,
    )

    # Display the response
    if verbose:
        show_response("Signup", url, response)

    return response


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import requests
from typing import Dict

# Local
from ..config import FRAMEWORK_ENDPOINT
from ..auth import get_header_from_token
from ..utils import show_response

def get(args) -> Dict:
    """Get project information

    Args:
        id: Text - Project ID
        name: Text - Project name
        verbose: bool - Verbose mode

    >>> mirinae project get -v
    >>> mirinae project get -v -id <project_id>
    >>> mirinae project get -v --name <project_name>
    """
    # Set the URL
    url = f"{FRAMEWORK_ENDPOINT}/project"

    # Update the URL with input parameters
    if args.id:
        url = url + f"?projectId={args.id}"
    if args.name:
        url = url + f"?name={args.name}"

    # Send the request
    response = requests.get(
        url,
        headers=get_header_from_token(),
    )

    # Display the response
    if args.verbose:
        show_response("Get", url, response)

    return response
